/*
 * This source is part of the
 *      _____  ___   ____
 *  __ / / _ \/ _ | / __/___  _______ _
 * / // / , _/ __ |/ _/_/ _ \/ __/ _ `/
 * \___/_/|_/_/ |_/_/ (_)___/_/  \_, /
 *                              /___/
 * repository.
 *
 * Copyright (C) 2014 Carmen Alvarez (c@rmen.ca)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ca.rmen.android.networkmonitor.app.service.scheduler;

import android.content.Context;

/**
 * Schedules a single Runnable to run periodically.
 */
public interface Scheduler {

    /**
     * Perform any initialization needed.
     */
    void onCreate(Context context);

    /**
     * Perform any shutdown tasks and free any resources.
     */
    void onDestroy();

    /**
     * Schedule the given task at the given interval in milliseconds.
     */
    void schedule(Runnable runnable, int interval);

    /**
     * Change the interval at which the existing task is scheduled.
     */
    void setInterval(int interval);
}
